OC.L10N.register(
    "core",
    {
    "Please select a file." : "Silakan pilih berkas",
    "File is too big" : "Berkas terlalu besar",
    "The selected file is not an image." : "Berkas terpilih bukan suatu gambar.",
    "The selected file cannot be read." : "Berkas terpilih tidak dapat dibaca.",
    "The file was uploaded" : "Berkas terunggah",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Berkas terunggah melampau parameter upload_max_filesize pada php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
    "The file was only partially uploaded" : "Berkas hanya sebagian terunggah",
    "No file was uploaded" : "Tidak ada berkas yang diunggah",
    "Missing a temporary folder" : "Folder sementara tidak ada",
    "Could not write file to disk" : "Tidak dapat menulis berkas ke diska",
    "A PHP extension stopped the file upload" : "Ekstensi PHP menghentikan proses unggah berkas",
    "Invalid file provided" : "Berkas tidak valid",
    "No image or file provided" : "Tidak ada gambar atau berkas yang disediakan",
    "Unknown filetype" : "Tipe berkas tidak dikenal",
    "An error occurred. Please contact your admin." : "Terjadi kesalahan. Silakan hubungi admin Anda.",
    "Invalid image" : "Gambar tidak valid",
    "No temporary profile picture available, try again" : "Tidak ada gambar profil sementara yang tersedia, coba lagi",
    "No crop data provided" : "Tidak ada data krop tersedia",
    "No valid crop data provided" : "Tidak ada data valid untuk dipangkas",
    "Crop is not square" : "Pangkas ini tidak persegi",
    "State token does not match" : "Token yang digunakan tidak cocok",
    "Invalid app password" : "Kata sandi aplikasi tidak valid",
    "Could not complete login" : "Tidak dapat menyelesaikan log masuk",
    "Your login token is invalid or has expired" : "Token log masuk Anda tidak valid atau sudah kedaluwarsa",
    "Login" : "Masuk",
    "Password reset is disabled" : "Setel ulang kata sandi dinonaktifkan",
    "Could not reset password because the token is expired" : "Tidak dapat mengatur ulang kata sandi karena token kedaluwarsa",
    "Could not reset password because the token is invalid" : "Tidak dapat mengatur ulang kata sandi karena token tidak valid",
    "%s password reset" : "%s kata sandi disetel ulang",
    "Password reset" : "Setel ulang kata sandi",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klik tombol berikut untuk menyetel ulang kata sandi Anda. Jika Anda tidak melakukan permintaan setel ulang kata sandi, abaikan surel ini.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klik tautan berikut untuk menyetel ulang kata sandi Anda. Jika Anda tidak melakukan permintaan setel ulang kata sandi, abaikan surel ini.",
    "Reset your password" : "Setel ulang kata sandi Anda",
    "Internal error" : "Kesalahan internal",
    "Nextcloud Server" : "Server Nextcloud",
    "Some of your link shares have been removed" : "Beberapa tautan berbagi Anda telah dihapus",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Dikarenakan isu bug keamanan, kami perlu menghapus beberapa tautan berbagi Anda. Silakan lihat tautan berikut untuk informasi lebih lanjut.",
    "Learn more ↗" : "Pelajari lebih lanjut ↗",
    "Preparing update" : "Mempersiapkan pembaruan",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Langkah perbaikan:",
    "Repair info:" : "Info perbaikan:",
    "Repair warning:" : "Peringatan perbaikan:",
    "Repair error:" : "Galat perbaikan:",
    "Turned on maintenance mode" : "Hidupkan mode perawatan",
    "Turned off maintenance mode" : "Matikan mode perawatan",
    "Maintenance mode is kept active" : "Mode Pemeliharaan masih aktif",
    "Updating database schema" : "Memperbarui skema basis data",
    "Updated database" : "Basis data terbaru",
    "Update app \"%s\" from App Store" : "Perbarui aplikasi \"%s\" dari App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema untuk %s dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\" terbarukan ke %2$s",
    "Set log level to debug" : "Atur log level ke debug",
    "Reset log level" : "Atur ulang log level",
    "Starting code integrity check" : "Memulai pengecekan integritas kode",
    "Finished code integrity check" : "Pengecekan integritas kode selesai",
    "%s (incompatible)" : "%s (tidak kompatibel)",
    "The following apps have been disabled: %s" : "Aplikasi berikut telah dinonaktifkan: %s",
    "Already up to date" : "Sudah yang terbaru",
    "Error occurred while checking server setup" : "Kesalahan tidak terduga saat memeriksa setelan server",
    "unknown text" : "teks tidak diketahui",
    "Hello world!" : "Halo dunia!",
    "sunny" : "cerah",
    "Hello {name}, the weather is {weather}" : "Halo {name}, saat ini {weather}",
    "Hello {name}" : "Halo {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ini adalah hasil pencarian Anda<script>alert(1)</script></strong>",
    "new" : "baru",
    "_download %n file_::_download %n files_" : ["unduh %n berkas"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Pembaruan sedang dalam proses, meninggalkan halaman ini mungkin dapat mengganggu proses di beberapa lingkungan.",
    "Update to {version}" : "Perbarui ke {version}",
    "An error occurred." : "Terjadi kesalahan.",
    "Please reload the page." : "Silakan muat ulang halaman.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Pembaruan gagal. Untuk informasi berikutnya <a href=\"{url}\">cek posting di forum</a> yang mencakup masalah kami.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Pembaruan gagal. Laporkan masalah ini ke <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunitas Nextcloud</a>.",
    "Continue to {productName}" : "Lanjutkan ke {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Pembaruan berhasil. Mengarahkan Anda ke {productName} dalam hitungan detik."],
    "Apps" : "Aplikasi",
    "More apps" : "Aplikasi lainnya",
    "No" : "Tidak",
    "Yes" : "Ya",
    "Failed to add the public link to your Nextcloud" : "Gagal menambah tautan publik ke Nextcloud Anda",
    "Start typing to search" : "Mulai mengetik untuk mencari",
    "Today" : "Hari ini",
    "Places" : "Tempat",
    "People" : "Orang",
    "Load more results" : "Muat lebih banyak hasil",
    "Log in" : "Masuk",
    "Logging in …" : "Log masuk...",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Terdeteksi multipel percobaan log masuk tidak valid dari IP Anda. Pencekalan log masuk berikutnya dilakukan hingga 30 detik.",
    "Server side authentication failed!" : "Otentikasi dari sisi server gagal!",
    "Please contact your administrator." : "Silakan hubungi administrator Anda.",
    "An internal error occurred." : "Terjadi kesalahan internal.",
    "Please try again or contact your administrator." : "Mohon coba lagi atau hubungi administrator Anda.",
    "Password" : "Kata Sandi",
    "Log in with a device" : "Log masuk dengan perangkat",
    "Your account is not setup for passwordless login." : "Akun Anda tidak diatur untuk masuk tanpa kata sandi.",
    "Your connection is not secure" : "Koneksi Anda tidak aman",
    "Passwordless authentication is only available over a secure connection." : "Otentikasi tanpa kata sandi hanya tersedia melalui koneksi aman.",
    "Browser not supported" : "Peramban tidak didukung",
    "Passwordless authentication is not supported in your browser." : "Otentikasi tanpa kata sandi tidak didukung peramban Anda.",
    "Reset password" : "Setel ulang kata sandi",
    "Back to login" : "Kembali ke log masuk",
    "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim surel setel ulang. Silakan hubungi administrator Anda.",
    "Password cannot be changed. Please contact your administrator." : "Kata sandi tidak dapat diubah. Silakan hubungi administrator Anda.",
    "New password" : "Kata sandi baru",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Berkas Anda terenkripsi. Tidak memungkinkan untuk mendapatkan kembali data Anda setelah kata sandi disetel ulang. Jika tidak yakin, silakan hubungi administrator Anda sebelum melanjutkan. Apa Anda ingin melanjutkan?",
    "I know what I'm doing" : "Saya tahu apa yang saya lakukan",
    "Resetting password" : "Menyetel ulang kata sandi",
    "Schedule work & meetings, synced with all your devices." : "Penjadwalan rapat & pekerjaan, tersinkronisasi dengan gawai Anda.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Simpan info teman dan kolega Anda dalam satu tempat, tanpa membocorkan privat mereka.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplikasi klien surel sederhana, terintegrasi dengan Berkas, Kontak, dan Kalender.",
    "Recommended apps" : "Aplikasi terekomendasi",
    "Loading apps …" : "Memuat aplikasi ...",
    "Could not fetch list of apps from the App Store." : "Tidak dapat mengambil daftar aplikasi dari App Store.",
    "App download or installation failed" : "Unduh aplikasi atau gagal instalasi",
    "Cannot install this app because it is not compatible" : "Tidak dapat memasang aplikasi ini karena tidak kompatibel",
    "Cannot install this app" : "Tidak dapat memasang aplikasi ini",
    "Skip" : "Lewati",
    "Installing apps …" : "menginstal aplikasi ...",
    "Install recommended apps" : "Instal aplikasi yang disarankan",
    "Settings menu" : "Menu Pengaturan",
    "Loading your contacts …" : "Memuat kontak Anda ...",
    "Looking for {term} …" : "Mencari {term}",
    "Reset search" : "Ulang pencarian",
    "Search contacts …" : "Cari kontak ...",
    "Could not load your contacts" : "Tidak dapat memuat kontak Anda",
    "No contacts found" : "Kontak tidak ditemukan",
    "Show all contacts" : "Tampilkan semua kontak",
    "Install the Contacts app" : "Instal aplikasi Kontak",
    "Search" : "Cari",
    "No results for {query}" : "Tidak ada hasil untuk {query}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Harap masukkan {minSearchLength} karakter atau lebih untuk mencari"],
    "An error occurred while searching for {type}" : "Terjadi kesalahan saat mencari {type}",
    "Search for {name} only" : "Cari {name} saja",
    "Loading more results …" : "Memuat hasil lainnya…",
    "Forgot password?" : "Lupa kata sandi?",
    "Back" : "Kembali",
    "Security warning" : "Peringatan keamanan",
    "Storage & database" : "Penyimpanan & Basis data",
    "Data folder" : "Folder data",
    "Install and activate additional PHP modules to choose other database types." : "Pasang dan aktifkan modul PHP tambahan untuk memilih tipe basis data lainnya.",
    "For more details check out the documentation." : "Untuk lebih rinci, periksa pada dokumentasi.",
    "Performance warning" : "Peringatan kinerja",
    "You chose SQLite as database." : "Anda memilih SQLite sebagai pangkalan data",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite hanya digunakan pada instalasi minimal dan lingkungan pengembangan. Untuk lingkungan produksi dianjurkan menggunakan backend pangkalan data lain.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jika menggunakan klien untuk sinkronisasi berkas, penggunaan SQLite sangat tidak dianjurkan.",
    "Database user" : "Pengguna basis data",
    "Database password" : "Kata sandi basis data",
    "Database name" : "Nama basis data",
    "Database tablespace" : "Tablespace basis data",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Harap tentukan nomor port beserta nama host (contoh., localhost:5432).",
    "Database host" : "Host basis data",
    "Installing …" : "Memasang …",
    "Install" : "Pasang",
    "Need help?" : "Butuh bantuan?",
    "See the documentation" : "Lihat dokumentasi",
    "Search {types} …" : "Cari {types} …",
    "Choose" : "Pilih",
    "Copy" : "Salin",
    "Move" : "Pindah",
    "OK" : "OK",
    "read-only" : "hanya-baca",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} berkas konflik"],
    "One file conflict" : "Satu berkas konflik",
    "New Files" : "Berkas Baru",
    "Already existing files" : "Berkas sudah ada",
    "Which files do you want to keep?" : "Berkas mana yang ingin Anda pertahankan?",
    "If you select both versions, the copied file will have a number added to its name." : "Jika Anda memilih kedua versi, berkas yang disalin akan memiliki nomor yang ditambahkan sesuai namanya.",
    "Cancel" : "Batal",
    "Continue" : "Lanjutkan",
    "(all selected)" : "(semua terpilih)",
    "({count} selected)" : "({count} terpilih)",
    "Error loading file exists template" : "Kesalahan memuat templat berkas yang sudah ada",
    "Saving …" : "Menyimpan ...",
    "seconds ago" : "beberapa detik yang lalu",
    "Connection to server lost" : "Koneksi ke server gagal",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Tidak dapat memuat laman, muat ulang dalam %n detik"],
    "Add to a project" : "Tambah ke proyek",
    "Show details" : "Tampilkan detail",
    "Hide details" : "Sembunyikan detail",
    "Rename project" : "Ubah nama proyek",
    "Failed to rename the project" : "Gagal mengubah nama proyek",
    "Failed to create a project" : "Gagal membuat proyek",
    "Failed to add the item to the project" : "Gagal menambahkan item ke proyek",
    "Connect items to a project to make them easier to find" : "Hubungkan item ke proyek agar mudah ditemukan",
    "Type to search for existing projects" : "Ketik untuk mencari proyek eksis",
    "New in" : "Terbaru",
    "View changelog" : "Lihat log pembaruan",
    "No action available" : "Aksi tidak tersedia",
    "Error fetching contact actions" : "Galat mengambil aksi kontak",
    "Non-existing tag #{tag}" : "Tag tidak ada #{tag}",
    "Restricted" : "Terbatas",
    "Invisible" : "Tersembunyi",
    "Delete" : "Hapus",
    "Rename" : "Ubah nama",
    "Collaborative tags" : "Tag kolaboratif",
    "No tags found" : "Tag tidak ditemukan",
    "Personal" : "Pribadi",
    "Admin" : "Admin",
    "Help" : "Bantuan",
    "Access forbidden" : "Akses ditolak",
    "Page not found" : "Halaman tidak ditemukan",
    "Back to %s" : "Kembali ke %s",
    "Too many requests" : "Terlalu banyak permintaan",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ada terlalu banyak permintaan dari jaringan Anda. Coba lagi nanti atau hubungi administrator Anda jika ini adalah kesalahan.",
    "Error" : "Kesalahan",
    "Internal Server Error" : "Kesalahan Server Internal",
    "The server was unable to complete your request." : "Peladen tidak dapat menyelesaikan permintaan Anda.",
    "If this happens again, please send the technical details below to the server administrator." : "Jika terjadi lagi, silakan sampaikan detail di bawah kepada administrator.",
    "More details can be found in the server log." : "Rincian lebih lengkap dapat ditemukan di log server.",
    "Technical details" : "Rincian teknis",
    "Remote Address: %s" : "Alamat remote: %s",
    "Request ID: %s" : "ID Permintaan: %s",
    "Type: %s" : "Tipe: %s",
    "Code: %s" : "Kode: %s",
    "Message: %s" : "Pesan: %s",
    "File: %s" : "Berkas: %s",
    "Line: %s" : "Baris: %s",
    "Trace" : "Jejak",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sepertinya Anda coba untuk menginstal ulang Nextcloud. Namun berkas CAN_INSTALL tidak ditemukan pada direktori konfigurasi. Silakan buat berkas tersebut untuk melanjutkan.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Tidak dapat membuang CAN_INSTALL dari direktori konfigurasi. Silakan lakukan secara manual.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikasi ini memerlukan JavaScript untuk dapat beroperasi dengan benar. Mohon {linkstart}aktifkan JavaScript{linkend} dan muat ulang halaman ini.",
    "Skip to main content" : "Lewati ke konten utama",
    "Skip to navigation of app" : "Lewati ke navigasi aplikasi",
    "Go to %s" : "Pergi ke %s",
    "Get your own free account" : "Dapatkan akun gratis Anda",
    "Connect to your account" : "Hubungkan ke akun Anda",
    "Please log in before granting %1$s access to your %2$s account." : "Silakan log masuk sebelum mengizinkan %1$s mengakses akun %2$s Anda.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jika Anda tidak mencoba menyiapkan perangkat atau aplikasi baru, seseorang mencoba menipu Anda agar memberi mereka akses ke data Anda. Dalam hal ini jangan lanjutkan dan hubungi administrator sistem Anda.",
    "Grant access" : "Berikan hak akses",
    "Account access" : "Akses akun",
    "You are about to grant %1$s access to your %2$s account." : "Anda akan memberikan izin %1$s akses ke akun %2$s Anda.",
    "Account connected" : "Akun terhubung",
    "Your client should now be connected!" : "Klien sudah terhubung!",
    "You can close this window." : "Anda dapat menutup jendela ini.",
    "Previous" : "Sebelumnya",
    "This share is password-protected" : "Berbagi ini dilindungi kata sandi",
    "Please type in your email address to request a temporary password" : "Silakan ketik alamat surel Anda untuk meminta kata sandi sementara",
    "Email address" : "Alamat surel",
    "Password sent!" : "Kata sandi terkirim!",
    "You are not authorized to request a password for this share" : "Anda tidak diizinkan untuk meminta kata sandi untuk pembagian ini",
    "Two-factor authentication" : "Otentikasi Two-factor",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Peningkatan keamanan telah diaktifkan pada akun Anda. Pilih faktor-kedua untuk autentikasi:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Tidak dapat memuat salah satu dari metode autentikasi faktor-kedua. Silakan hubungi admin Anda.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Autentikasi faktor-kedua diwajibkan, namun belum terkonfigurasi pada akun Anda. Hubungi admin untuk asistensi.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Autentikasi faktor-kedua diwajibkan, namun belum terkonfigurasi pada akun Anda. Silakan lanjutkan untuk menyetel autentikasi faktor-kedua.",
    "Set up two-factor authentication" : "Setel autentikasi faktor-kedua",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Autentikasi faktor-kedua diwajibkan, namun belum terkonfigurasi pada akun Anda. Gunakan salah satu kode cadangan untuk log masuk, atau hubungi admin untuk asistensi.",
    "Use backup code" : "Gunakan kode cadangan",
    "Cancel login" : "Batalkan log masuk",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Peningkatan keamanan diwajibkan untuk akun Anda. Pilih penyedia setelan:",
    "Error while validating your second factor" : "Galat ketika memvalidasi faktor kedua Anda",
    "Access through untrusted domain" : "Akses melalui domain tidak terpercaya",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Silakan hubungi administrator Anda. Apabila Anda adalah administrator dari instalasi ini, setel parameter \"trusted_domains\" pada config/config.php seperti contoh yang tersedia pada config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Info lebih lanjut mengenai pengaturan ini, dapat ditemukan pada %1$sdokumentasi%2$s.",
    "App update required" : "Diperlukan perbarui aplikasi",
    "%1$s will be updated to version %2$s" : "%1$s akan diperbarui ke versi %2$s",
    "The following apps will be updated:" : "Aplikasi berikut akan diperbarui:",
    "These incompatible apps will be disabled:" : "Aplikasi yang tidak kompatibel berikut akan dinonaktifkan:",
    "The theme %s has been disabled." : "Tema %s telah dinonaktfkan.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pastikan bahwa basis data, folder konfig, dan folder data telah dicadangkan sebelum melanjutkan.",
    "Start update" : "Jalankan pembaruan",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Untuk menghindari waktu habis dengan instalasi yang lebih besar, Anda bisa menjalankan perintah berikut dari direktori instalasi Anda:",
    "Detailed logs" : "Log detail",
    "Update needed" : "Pembaruan dibutuhkan",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Lihat <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentasi</a> untuk panduan.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Saya paham jika melakukan proses pemutakhiran via antarmuka web, berisiko komunikasi terhenti dan kemungkinan kehilangan data. Saya punya cadangan dan paham bagaimana cara pemulihan, jika terjadi kegagalan.",
    "Upgrade via web on my own risk" : "Pemutakhiran via web adalah risiko saya",
    "Maintenance mode" : "Mode pemeliharaan",
    "This %s instance is currently in maintenance mode, which may take a while." : "Instansi %s ini sedang dalam modus pemeliharaan, mungkin memerlukan beberapa saat.",
    "This page will refresh itself when the instance is available again." : "Laman ini akan dimuat otomatis saat instalasi kembali tersedia.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Hubungi administrator sistem Anda jika pesan ini terus muncul atau muncul tiba-tiba.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mengobrol, panggilan video, berbagi layar, rapat daring, dan konferensi web - melalui peramban dan menggunakan aplikasi pada gawai.",
    "You have not added any info yet" : "Anda belum menambahkan info apa pun",
    "{user} has not added any info yet" : "{user} belum menambahkan info apa pun",
    "Edit Profile" : "Sunting profil",
    "Error loading message template: {error}" : "Kesalahan memuat templat pesan: {error}",
    "Very weak password" : "Kata sandi sangat lemah",
    "Weak password" : "Kata sandi lemah",
    "So-so password" : "Kata sandi lumayan",
    "Good password" : "Kata sandi baik",
    "Strong password" : "Kata sandi kuat",
    "Profile not found" : "Profil tidak ditemukan",
    "The profile does not exist." : "Profil tidak ada.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Kemungkinan direktori data dan berkas Anda dapat diakses dari internet karena berkas .htaccess tidak berfungsi.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informasi bagaimana kesesuaian konfigurasi peladen Anda, silakan lihat <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasi</a>.",
    "Show password" : "Tampilkan kata sandi",
    "Configure the database" : "Konfigurasikan basis data",
    "Only %s is available." : "Hanya %s yang tersedia"
},
"nplurals=1; plural=0;");
